Function esp32_simple::ble::initialize

source ·
pub fn initialize(power_level: PowerLevel) -> Result<()>
Initializes the BLE device with the specified power level for advertising and scanning.

Arguments

  • power_level - The power level to use for both advertising and scanning.

Returns

Ok(()) on success.

Errors

Returns an error if the BLE device cannot be configured with the specified power levels.